Generic testing utilities.
Modules
- cli_
harness - fd_
checker - Central-difference finite-difference checking harness for tests.
- reference
- End-to-end quality comparison against mature, standard statistical tools.
Macros
- assert_
central_ difference_ array - Assert that a central difference of an array-producing function matches the analytical derivative.
- gam_
binary - Path to the
gamCLI binary for tests that shell out to it.
Structs
Functions
- assert_
matrix_ derivativefd - Asserts that a finite difference dense matrix closely matches an analytically computed directional derivative matrix, both in tolerance and in component-wise sign.
- assert_
matrix_ derivativefd_ rel - Asserts that a finite difference dense matrix matches an analytically
computed directional derivative matrix to a relative tolerance
rel_tol·(1 + |analytic|), plus component-wise sign agreement. - binomial_
location_ scale_ base_ fixture - no_
densify_ design - Build an operator-backed
DesignMatrixfrom a dense array that will panic if any consumer tries to densify it. See [NoDensifyOperator]. - spec_
from_ dense - spec_
from_ dense_ with_ priority