pub fn assert_matrix_derivativefd(
fd: &Array2<f64>,
analytic: &Array2<f64>,
tol: f64,
label: &str,
)Expand description
Asserts that a finite difference dense matrix closely matches an analytically computed directional derivative matrix, both in tolerance and in component-wise sign.