Crate gam_test_support

Crate gam_test_support 

Generic testing utilities.

Modules

cli_harness
fd_checker
Central-difference finite-difference checking harness for tests.
reference
End-to-end quality comparison against mature, standard statistical tools.

Macros

assert_central_difference_array
Assert that a central difference of an array-producing function matches the analytical derivative.
gam_binary
Path to the gam CLI binary for tests that shell out to it.

Structs

BinomialLocationScaleBaseFixture

Functions

assert_matrix_derivativefd
Asserts that a finite difference dense matrix closely matches an analytically computed directional derivative matrix, both in tolerance and in component-wise sign.
assert_matrix_derivativefd_rel
Asserts that a finite difference dense matrix matches an analytically computed directional derivative matrix to a relative tolerance rel_tol·(1 + |analytic|), plus component-wise sign agreement.
binomial_location_scale_base_fixture
no_densify_design
Build an operator-backed DesignMatrix from a dense array that will panic if any consumer tries to densify it. See [NoDensifyOperator].
spec_from_dense
spec_from_dense_with_priority